oc\_ocdm.graph.entities.bibliographic.reference\_annotation module
------------------------------------------------------------------

.. automodule:: oc_ocdm.graph.entities.bibliographic.reference_annotation
   :members:
   :undoc-members:
   :show-inheritance:
